==> openshift-model-console-5.9.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadSpecBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleCLIDownloadSpecBuilder extends io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecBuilder>{
  public ConsoleCLIDownloadSpecBuilder() {
    this(false);
  }
  public ConsoleCLIDownloadSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleCLIDownloadSpec(), validationEnabled);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleCLIDownloadSpec(), validationEnabled);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec instance) {
    this(fluent, instance, false);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withLinks(instance.getLinks()); 
    this.validationEnabled = validationEnabled; 
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec instance) {
    this(instance,false);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withLinks(instance.getLinks()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec build() {
    ConsoleCLIDownloadSpec buildable = new ConsoleCLIDownloadSpec(fluent.getDescription(),fluent.getDisplayName(),fluent.getLinks());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleCLIDownloadSpecBuilder that = (ConsoleCLIDownloadSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-console-5.11.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadSpecBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleCLIDownloadSpecBuilder extends io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecBuilder>{
  public ConsoleCLIDownloadSpecBuilder() {
    this(false);
  }
  public ConsoleCLIDownloadSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleCLIDownloadSpec(), validationEnabled);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleCLIDownloadSpec(), validationEnabled);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec instance) {
    this(fluent, instance, false);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withLinks(instance.getLinks()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec instance) {
    this(instance,false);
  }
  public ConsoleCLIDownloadSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withLinks(instance.getLinks()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadSpec build() {
    ConsoleCLIDownloadSpec buildable = new ConsoleCLIDownloadSpec(fluent.getDescription(),fluent.getDisplayName(),fluent.getLinks());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleCLIDownloadSpecBuilder that = (ConsoleCLIDownloadSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
